@@ -8,7 +8,15 @@ from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariateSpline, RectBivariateSpline
 from . import cocos
 
-log = logging.getLogger()
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
+hnd = logging.StreamHandler()
+hnd.setFormatter(fmt)
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('mapeq')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
+
 
 def get_nearest_index(tim_eq, tarr):
     """Find nearest time index for a given time"""
@@ -206,11 +214,11 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
     nrz_in = r_in.shape[-1]
 
     if r_in.shape != z_in.shape:
-        log.error('r_in and z_in must have the same shape')
+        logger.error('r_in and z_in must have the same shape')
         return
 
     if r_in.ndim == 2 and r_in.shape[0] != nt:
-        log.error('Time array missmatching first dim of r_in')
+        logger.error('Time array missmatching first dim of r_in')
         return
 
     if np.size(r_in, 0)!= nt:
@@ -238,7 +246,7 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
     psi_sign = sigma_ip*cocos.sigma['bp'][jc_in]
     psi_2pi  = (2.*np.pi)**ebp_in
     psi_fac = psi_sign*psi_2pi
-    log.debug('COCOS %d, Sign Bt %d, Sign Ip %d' %(cocos_in, sign_b0, sign_ip))
+    logger.debug('COCOS %d, Sign Bt %d, Sign Ip %d' %(cocos_in, sign_b0, sign_ip))
 
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
@@ -310,7 +318,7 @@ def Bmesh(eqm, t_in=None):
     psi_sign = cocos.sigma['bp'][jc_in]
     psi_2pi  = (2.*np.pi)**ebp_in
     psi_fac = psi_sign*psi_2pi
-    log.info('COCOS %d' %cocos_in)
+    logger.info('COCOS %d' %cocos_in)
 
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
@@ -462,7 +470,7 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
         try:
             cgen = _contour.QuadContourGenerator(R, Z, eqm.pfm[:nr, :nz, i].T, None, True, 0)
         except Exception as e:
-            log.exception(R.shape, Z.shape, eqm.pfm[:nr, :nz, i].T.shape)
+            logger.exception(R.shape, Z.shape, eqm.pfm[:nr, :nz, i].T.shape)
             raise e 
 
         Rs_t = []
@@ -566,7 +574,7 @@ def cross_surf(eqm, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in='
         ind_gt = (rho_line[i] > rho)
         ind_cross = [j for j, x in enumerate(np.diff(ind_gt)) if x]
         if len(ind_cross) > 2:
-            log.warning('More than 2 intersections, problems')
+            logger.warning('More than 2 intersections, problems')
             zout[jt, :] = 0
             Rout[jt, :] = 0
             continue
@@ -642,7 +650,7 @@ def cross_sep(eqm, r_in=1.65, z_in=0, theta_in=0, t_in=None):
         ind_gt = (psi_line[i] > psi_sep[ii])
         ind_cross = [j for j, x in enumerate(np.diff(ind_gt)) if x]
         if len(ind_cross) > 2:
-            log.warning('More than 2 intersections, problems')
+            logger.warning('More than 2 intersections, problems')
             zout[jt, :] = 0
             Rout[jt, :] = 0
             continue
