@@ -5,12 +5,14 @@ import numpy as np
 
 from . import sfobj, SFREAD, parse_kwargs
 
-log = logging.getLogger()
-
-
-class EMPTY:
-
-    pass
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
+hnd = logging.StreamHandler()
+hnd.setFormatter(fmt)
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('sf2equ')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
 
 
 class EQU:
@@ -86,17 +88,17 @@ class EQU:
                 ind_sol  = np.arange(self.lpfp[jt] + 3, self.lpfp[jt] + 3 + self.lpfe[jt])
                 self.ind_sort.append(np.append(ind_core, ind_sol))
         else:
-            log.error('Problems opening %s:%s:%d for shot %d' %(exp, diag, ed, nshot))
+            logger.error('Problems opening %s:%s:%d for shot %d' %(exp, diag, ed, nshot))
             return
 
-        log.info('Reading equ scalars')
+        logger.info('Reading equ scalars')
         self.read_scalars()
-        log.info('Reading equ 1d profiles')
+        logger.info('Reading equ 1d profiles')
         self.read_profiles()
-        log.info('Reading equ PFM')
+        logger.info('Reading equ PFM')
         self.read_pfm()
 
-        log.info('Detected COCO %d' %self.cocos)
+        logger.info('Detected COCO %d' %self.cocos)
 
         if 'tbeg' in kwargs.keys():
             tbeg = kwargs['tbeg']
@@ -223,7 +225,7 @@ class EQU:
             ## Plasma current[A]
             self.ipipsi = self.sf.getobject('IpiPSI')[:nt]
         except:
-            log.exception('Signal IpiPSI not found')
+            logger.exception('Signal IpiPSI not found')
 
 
     def read_profiles(self):
@@ -272,7 +274,7 @@ class EQU:
         profs = ('TFLx', 'PFL', 'FFP', 'Qpsi', 'Rinv', 'R2inv', 'Bave', 'B2ave')
 
         if var_name not in profs:
-            log.error('SignalGroup %s unknown' %var_name)
+            logger.error('SignalGroup %s unknown' %var_name)
             return None
 
         tmp = self.sf.getobject(var_name)
@@ -312,7 +314,7 @@ class EQU:
 # Pairs prof, d(prof)/d(psi)
 
         if var_name not in mixed:
-            log.error('%s not one of the mixed quanties Vol, Area, Pres, Jpol' %var_name)
+            logger.error('%s not one of the mixed quanties Vol, Area, Pres, Jpol' %var_name)
             return None, None
 
         tmp = self.sf.getobject(var_name)
@@ -320,8 +322,8 @@ class EQU:
         dvar = tmp[1::2, :nt]
 
         nrho = np.max(self.lpfp + 1 + self.lpfe)
-        info  = EMPTY()
-        dinfo = EMPTY()
+        info  = type('', (), {})()
+        dinfo = type('', (), {})()
         for key, val in tmp.__dict__.items():
             if key != 'data':
                 info.__dict__[key] = val
@@ -347,4 +349,4 @@ if __name__ == '__main__':
 
     nshot = 28053
     eqm = EQU(nshot)
-    log.info(eqm.ssqnames)
+    logger.info(eqm.ssqnames)
