@@ -208,7 +208,7 @@ class SFREAD:
             logger.debug('%d %s %s %d', nshot, diag, exp, ed)
             self.sfile, self.ed = manage_ed.sf_path(nshot, diag, exp=exp, ed=ed)
             if self.sfile is None:
-                logger.error('Shotfile not found')
+                logger.error('Shotfile not found for %s:%s(%d) #%d', exp, diag, ed, nshot)
                 return
             else:
                 self.shot = nshot
@@ -304,7 +304,7 @@ class SFREAD:
         obj = str_byt.to_str(obj)
         data = None
         if obj not in self.sfh.keys():
-            logger.error('Signal %s not found in diag %s' %(obj, diag))
+            logger.error('Signal %s:%s not found for #%d', self.diag, obj, self.shot)
             return None
 # Don't uncomment the following lines, to allow 1 cal and 1 uncal reading
 #        if obj in self.cache.keys(): 
