@@ -3,14 +3,20 @@ import ctypes as ct
 import numpy as np
 from . import sfdics, str_byt
 
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
+hnd = logging.StreamHandler()
+hnd.setFormatter(fmt)
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('ww')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
+
 wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/@sys/libddww8.so.8.1'
 if not os.path.isfile(wwlib):
     wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/amd64_sles11/libddww8.so.8.1'
 libddww = ct.cdll.LoadLibrary(wwlib)
 
-log = logging.getLogger()
-
-
 def getError(error):
 
     """ Check if an error/warning occured. """
@@ -87,7 +93,7 @@ class WW:
             _space = ct.c_char_p( space )
 
             result = libddww.wwclose_(_error , self._diaref , _disp , _space , ldisp , lspace )
-            log.info('Close: ', result, error.value, ' Edition', self.edition.value)
+            logger.info('Close: ', result, error.value, ' Edition', self.edition.value)
             if getError( error ):
                 raise Exception('ww: Error Closing Shotfile')
             del self._diaref
@@ -145,7 +151,7 @@ class WW:
 
 
     def SetObject(self, signame, data):
-        log.info('Setting %s' %(signame))
+        logger.info('Setting %s' %(signame))
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(signame)
             otype = info['otype']
@@ -233,7 +239,7 @@ class WW:
                 if getError( error ):
                     raise Exception('ww: Error Writing %s %s' %(lbl, sign) )
                 else:
-                    log.info('Written %s %s' %(lbl, sign))
+                    logger.info('Written %s %s' %(lbl, sign))
 
 
     def SetSignalGroup(self, signame, data):
@@ -258,7 +264,7 @@ class WW:
                     for j in range(data.shape[2]):
                         indices = [1 + i, 1 + j, 1]
                         self.SetSignal(signame, data[:, i, j], indices=indices)
-        log.info('Written Signal Group %s' %signame)
+        logger.info('Written Signal Group %s' %signame)
 
         return True
 
@@ -282,7 +288,7 @@ class WW:
                     sizes[1] = sizes[2]
             else:
                 nt = 1
-            log.debug(areaname, dtype, nt, data.shape, sizes[0:3])
+            logger.debug(areaname, dtype, nt, data.shape, sizes[0:3])
             error  = ct.c_int32(0)
             name   = ct.c_char_p(areaname)
             lname  = ct.c_uint64(len(areaname))
@@ -301,7 +307,7 @@ class WW:
             if getError(error):
                 raise Exception('ww.shotfile.SetAreabase: Error writing areabase %s' %areaname)
             else:
-                log.info('Written Areabase %s' %areaname, sizes[0:3])
+                logger.info('Written Areabase %s' %areaname, sizes[0:3])
 
 
     def SetParameter(self, set_name, par_name, data):
@@ -315,16 +321,16 @@ class WW:
             ctyp  = sfdics.typ2ct[dattype]
             set_name = str_byt.to_byt(set_name)
             par_name = str_byt.to_byt(par_name)
-            log.info('PN %s' %par_name)
+            logger.info('PN %s' %par_name)
             data = np.atleast_1d(data)
-            log.debug('Data', data, dattype )
+            logger.debug('Data', data, dattype )
             ndata = len(data)
             nitem = info['items']
             if ndata > nitem:
-                log.error('Too many %d entries for par_nam %s, more than in sfh %d' %(ndata, par_name, nitem))
+                logger.error('Too many %d entries for par_nam %s, more than in sfh %d' %(ndata, par_name, nitem))
                 return
             if ndata == 0:
-                log.error('No data for par_nam %s' %par_name)
+                logger.error('No data for par_nam %s' %par_name)
                 return
             if ndata < nitem:
                 data = np.zeros(nitem, dtype=sfdics.typ2np[dattype])
@@ -372,7 +378,7 @@ class WW:
                 raise Exception('ww: Error Writing Parameters into %s -> %s' %(set_name.decode('utf-8'), par_name.decode('utf-8') ) )
 
             else:
-                log.info('   PN %s' %par_name.decode('utf8'))
+                logger.info('   PN %s' %par_name.decode('utf8'))
 
 
 def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
@@ -382,14 +388,14 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
     ww = WW()
 
     os.chdir(sfhdir)
-    log.info(exp, diag, nshot)
+    logger.info(exp, diag, nshot)
     if not ww.Open(exp, diag, nshot):
-        log.error('Problems opening shotfile')
+        logger.error('Problems opening shotfile')
         return
 
     otype = {}
     for obj, data in data_d.items():
-        log.debug(obj)
+        logger.debug(obj)
         otype[obj] = ww._wwoinfo(obj)['otype']
         if otype[obj] == 8:
             ww.SetObject(obj, data)
@@ -400,7 +406,7 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
 
     for obj, data in data_d.items():
         if otype[obj] == 4:
-            log.info('Writing PS %s' %obj)
+            logger.info('Writing PS %s' %obj)
             for pn, pdata in data.items():
                 ww.SetParameter(obj, pn, pdata)
         if otype[obj] in (6, 7):
